@@ -3,7 +3,7 @@ A plugin for setuptools to find files under the Mercurial version control
 system which uses the Python library by default and falls back to use the
 command line programm hg(1).
 """
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 __author__ = 'Jannis Leidel'
 __all__ = ['hg_file_finder']
 
@@ -24,12 +24,16 @@ def find_files_with_cmd(dirname="."):
     """
     Use the hg command to recursively find versioned files in dirname.
     """
-    proc = subprocess.Popen(['hg', 'locate'],
-                            stdin=subprocess.PIPE,
-                            stdout=subprocess.PIPE,
-                            stderr=subprocess.PIPE,
-                            cwd=dirname)
-    stdout, stderr = proc.communicate()
+    try:
+        proc = subprocess.Popen(['hg', 'locate'],
+                                stdin=subprocess.PIPE,
+                                stderr=subprocess.PIPE,
+                                stdout=subprocess.PIPE,
+                                cwd=dirname)
+        stdout, stderr = proc.communicate()
+    except Exception, e:
+        # Let's behave a bit nicer and return nothing if something fails.
+        return []
     return stdout.splitlines()
 
 def find_files_with_lib(dirname):
@@ -85,15 +89,3 @@ def hg_file_finder(dirname="."):
     if hg is None:
         return find_files_with_cmd(dirname)
     return find_files_with_lib(dirname)
-
-def main():
-    import sys
-    from pprint import pprint
-    try:
-        dirname = sys.argv[1]
-    except IndexError:
-        dirname = "."
-    pprint(list(hg_file_finder(dirname)))
-
-if __name__ == '__main__':
-    main()
